@@ -8,4 +8,4 @@
 # }
 
 # Remove CRAN note on no visible binding for global variable
-utils::globalVariables(c('.', '..density..'))
+utils::globalVariables('.')
